Enum StudyCreateOutcome
pub enum StudyCreateOutcome {
Created(StudyId),
Occupied,
}Expand description
The result of an atomic StudyCatalog::create_if_empty operation.
Variants
Created(StudyId)
The caller created the only study in an empty catalog.
Occupied
The catalog already contained at least one study and was unchanged.