Struct OutboxRecord
pub struct OutboxRecord {
pub key: OutboxKey,
pub terminal: TerminalOutcome,
pub phase: OutboxPhase,
pub intent: FinalizationIntent,
pub completed_effects: Vec<OutboxEffectKey>,
}Expand description
A durable snapshot of one outbox record.
Fields
key: OutboxKeyThe trial/owner-epoch key.
terminal: TerminalOutcomeThe terminal outcome that was committed with the intent.
phase: OutboxPhaseThe current replay phase.
intent: FinalizationIntentAll callback state and effect intents discovered so far.
completed_effects: Vec<OutboxEffectKey>Effects whose observable operation has completed.