Struct LeaseObservation
pub struct LeaseObservation { /* private fields */ }Expand description
A read-only complete lease observation used for conditional failover.
The heartbeat sequence is intentionally separate from the timestamp. Two observations with the same timestamp are still distinguishable when one heartbeat was renewed in between them.
Implementations
impl LeaseObservation
impl LeaseObservation
pub const fn state(self) -> TrialState
pub const fn state(self) -> TrialState
The observed trial state.
pub const fn heartbeat_millis(self) -> Option<u64>
pub const fn heartbeat_millis(self) -> Option<u64>
The last supplied heartbeat timestamp.
pub const fn heartbeat_seq(self) -> u64
pub const fn heartbeat_seq(self) -> u64
The monotonically increasing heartbeat observation sequence.