Function require_objective_value
pub fn require_objective_value(trial: &FrozenTrial) -> Result<&[f64]>Expand description
Convenience: the objective values of a completed trial, or an error.
Exists so that call sites which require a value do not have to invent an error message each time.
Errors
Error::NotFound if the trial has no
objective value.